pub fn binomial_square<F: Field, R: Algebra<F>, const D: usize>(
a: &[R; D],
res: &mut [R; D],
w: F,
)Expand description
Square a vector representing an element in a binomial extension.
This is optimized for the case that R is a prime field or its packing.